@@ -1,7 +1,7 @@
 # @Author: chunyang.xu
 # @Email:  398745129@qq.com
 # @Date:   2020-06-10 14:40:50
-# @Last Modified time: 2021-04-19 17:03:28
+# @Last Modified time: 2021-08-09 15:45:21
 # @github: https://github.com/longfengpili
 
 # !/usr/bin/env python3
@@ -32,14 +32,19 @@ class SqlMysqlCompile(SqlCompile):
     def __init__(self, tablename):
         super(SqlMysqlCompile, self).__init__(tablename)
 
-    def create(self, columns, indexes):
+    def create(self, columns, indexes, index_part=128):
         'mysql 暂不考虑索引'
         sql = self.create_nonindex(columns)
-        # if indexes and not isinstance(indexes, list):
-        #     raise TypeError(f"indexes must be a list !")
-        # if indexes:
-        #     indexes = ','.join(indexes)
-        #     sql = f"{sql.replace(';', '')}interleaved sortkey({indexes});"
+
+        if indexes and not isinstance(indexes, list):
+            raise TypeError(f"indexes must be a list, but got {indexes} !")
+
+        if indexes:
+            for index in indexes:
+                index_sqlexpr = f"index {index}_index ({index}({index_part}))"
+                sql = sql.replace(');', f",\n{index_sqlexpr});")
+                continue
+
         return sql
 
     def dumpsql(self, columns, dumpfile, fromtable=None, condition=None):
